@@ -345,10 +345,8 @@ class Interviews():
             super_log(json.dumps(topic_status,ensure_ascii=False,indent=4),'chat_with_deepmodel-状态更新')
         except Exception as e:
             logger.error(f"Error 深度模型错误了,{e}")
-            raise Exception("深度模型错误了") from e
-        return "success"
-
-
+            raise Exception(f"深度模型错误了 {e}") from e
+        return {"status":"success"}
 
     async def chat_with_iv(self,prompt_with_history,user_id,topic):
         try:
