@@ -100,7 +100,7 @@ class MemoryCardGenerateEasy(BaseModel):
     @field_validator('time')
     @classmethod
     def validate_time_format(cls, v: str) -> str:
-        combined_regex = r"^(?:(\d{4}|-{4})年(\d{2}|-{2})月(\d{2}|-{2})日|(\d+)到(\d+)岁|-{2}到-{2}岁|-{1,}到(\d+)岁|(\d+)到-{1,}岁)$"
+        combined_regex = r"^(?:(\d{4}|-{4}|-{2})年(\d{2}|-{2})月(\d{2}|-{2})日|(\d+)到(\d+)岁|-{2}到-{2}岁|-{1,}到(\d+)岁|(\d+)到-{1,}岁)$"
         match = re.match(combined_regex, v)
         if match:
             return v
@@ -118,7 +118,7 @@ class MemoryCardGenerate(BaseModel):
     @field_validator('time')
     @classmethod
     def validate_time_format(cls, v: str) -> str:
-        combined_regex = r"^(?:(\d{4}|-{4})年(\d{2}|-{2})月(\d{2}|-{2})日|(\d+)到(\d+)岁|-{1,}到(\d+)岁|(\d+)到-{1,}岁)$"
+        combined_regex = r"^(?:(\d{4}|-{4}|-{2})年(\d{2}|-{2})月(\d{2}|-{2})日|(\d+)到(\d+)岁|-{1,}到(\d+)岁|(\d+)到-{1,}岁)$"
         match = re.match(combined_regex, v)
         if match:
             return v
