@@ -118,6 +118,11 @@ async def generate_llm_response(prompt: str, stream: bool, model: str,
             except asyncio.CancelledError as e:
                 # logger.error("Streaming connection closed by client.")
                 raise e
+            
+            except Exception as e:
+                yield f"Error details: {str(e)}"
+            finally:
+                print("Event generator finished.")
 
         return EventSourceResponse(event_publisher())
 
